/* eslint-disable import/prefer-default-export */
import { getApiQueryParams } from './sportstake';
import { getFixtures, getLatestResults } from './services';

export async function getAPIData(page) {
  let response = {};

  switch (page?.template) {
    case 'sportstake_fixtures':
      {
        const filteredArray = page?.sections?.main?.modules.filter(
          (x) => x.value_type === 'template_block'
        );

        const responseArray = await Promise.all(
          filteredArray.map(async (module) => {
            const moduleName = module.name;
            const query = getApiQueryParams(moduleName);

            const res = await getFixtures(`${query.lotteryName}/${query.listType}`);
            return { name: moduleName, result: res };
          })
        );

        response = {
          data: responseArray.filter((n) => n),
        };
      }
      break;
    case 'sportstake_results':
      {
        const filteredArray = page?.sections?.main?.modules.filter(
          (x) => x.value_type === 'template_block'
        );

        const responseArray = await Promise.all(
          filteredArray.map(async (module) => {
            const moduleName = module.name;
            const newSportStakes =
              moduleName.includes('cricket') ||
              moduleName.includes('sportstake4') ||
              moduleName.includes('rugby');
            const query = getApiQueryParams(moduleName);
            const endPoint = newSportStakes
              ? `${query.lotteryName}`
              : `${query.lotteryName}?list_type=${query.listType}`;

            const res = await getLatestResults(endPoint);
            return { name: moduleName, result: res };
          })
        );

        response = {
          template: page?.template,
          name: page?.title,
          data: responseArray,
        };
      }
      break;
    default:
      return null;
  }

  return {
    props: response,
  };
}
